package api

import (
	"github.com/gin-gonic/gin"
	"node_monitor/dto"
	"node_monitor/middleware"
	"node_monitor/services"
)

type NodeApi struct {
}

func NodeRegister(route *gin.RouterGroup) {
	node := NodeApi{}
	route.POST("/add", node.Add)
	route.POST("/delete", node.Delete)
	route.POST("/edit", node.edit)
	route.GET("/getnode", node.GetNode)
}

func (c *NodeApi) GetNode(ctx *gin.Context) {
	nodeservice := services.NodeService{}
	node, err := nodeservice.GetNode(ctx)
	if err != nil {
		middleware.ResponseError(ctx, 2002, err)
		return
	}

	middleware.ResponseSuccess(ctx, node)
	return
}

func (c *NodeApi) Add(ctx *gin.Context) {
	addInput := &dto.AddNodeInput{}
	if err := addInput.BindingValidParams(ctx); err != nil {
		middleware.ResponseError(ctx, 2001, err)
		return
	}
	nodeservice := services.NodeService{}
	err := nodeservice.AddNode(ctx, addInput)
	if err != nil {
		middleware.ResponseError(ctx, 2002, err)
		return
	}
	middleware.ResponseSuccess(ctx, "")
	return
}

func (c *NodeApi) Delete(ctx *gin.Context) {
	addInput := &dto.RemoveNodeInput{}
	if err := addInput.BindingValidParams(ctx); err != nil {
		middleware.ResponseError(ctx, 2001, err)
		return
	}
	nodeservice := services.NodeService{}
	err := nodeservice.DeleteNode(ctx, addInput)
	if err != nil {
		middleware.ResponseError(ctx, 2002, err)
		return
	}
	middleware.ResponseSuccess(ctx, "")
	return
}

func (c *NodeApi) edit(ctx *gin.Context) {

}
