package g

import (
	"github.com/cihub/seelog"
	"gorm.io/driver/sqlite"
	"gorm.io/gorm"
	"gorm.io/gorm/schema"
	"io"
	"log"
	"node_monitor/dao"
	"os"
)

var (
	Root string
	Db   *gorm.DB
)

func InitDB() {
	Root, _ = os.Getwd()

	if !IsExist(Root + "/db/" + "database.db") {
		if !IsExist(Root + "/db/" + "database-base.db") {
			log.Fatalln("[Fault]db file:", Root+"/db/"+"database(-base).db", "both not existent.")
		}
		src, err := os.Open(Root + "/db/" + "database-base.db")
		if err != nil {
			log.Fatalln("[Fault]db-base file open error.")
		}

		dst, err := os.OpenFile(Root+"/db/"+"database.db", os.O_WRONLY|os.O_CREATE, 0644)
		if err != nil {
			log.Fatalln("[Fault]db-base file copy error.")
		}
		//defer dst.Close()
		io.Copy(dst, src)
	}

	db, err := gorm.Open(sqlite.Open(Root+"/db/database.db"), &gorm.Config{
		NamingStrategy: schema.NamingStrategy{
			TablePrefix:   "",   // table name prefix, table for `User` would be `t_users`
			SingularTable: true, // use singular table name, table for `User` would be `user` with this option enabled
			// use name replacer to change struct/field name before convert it to db name
		},
	})
	if err != nil {
		panic("failed to connect database")
	}

	err = db.AutoMigrate(&dao.Node{})
	if err != nil {
		seelog.Debug("[node] AutoMigrate error" + err.Error())
		return
	}

	err = db.AutoMigrate(&dao.PingLog{})
	if err != nil {
		seelog.Debug("[node] AutoMigrate error" + err.Error())
		return
	}

	Db = db
}

//// 添加节点
//func AddNode(node *Node) {
//
//	db := Db.Where("host = ?", node.Host).First(&node)
//	if db.Error != nil {
//		seelog.Debug("[node] create error" + db.Error.Error())
//		db = Db.Create(&node)
//		if db.Error != nil {
//			seelog.Debug("[node] create error" + db.Error.Error())
//		}
//	}
//}
//
//// 删除节点
//func DeleteNode(host string) {
//	db := Db.Where("host = ?", host).Delete(&Node{})
//	if db.Error != nil {
//		seelog.Debug("[node] delete error" + db.Error.Error())
//	}
//}
