package services

import (
	"github.com/gin-gonic/gin"
	"node_monitor/dao"
	"node_monitor/dto"
	"node_monitor/g"
	"node_monitor/middleware"
)

type NodeService struct {
}

func (as *NodeService) GetNode(c *gin.Context) ([]*dao.Node, error) {
	tx := g.Db
	node := &dao.Node{}
	getNode, err := node.GetNode(c, tx)
	if err != nil {
		return nil, err
	}
	return getNode, nil
}

func (as *NodeService) AddNode(c *gin.Context, input *dto.AddNodeInput) error {
	tx := g.Db
	node := &dao.Node{
		Name: input.Name,
		Host: input.Host,
		Port: input.Port,
		Url:  input.Url,
	}

	err := node.IsExists(c, tx, input.Host)
	if err != nil {
		return err
	}

	if err := node.Save(c, tx); err != nil {
		middleware.ResponseError(c, 2002, err)
		return err
	}

	return nil
}

func (as *NodeService) DeleteNode(c *gin.Context, removeInput *dto.RemoveNodeInput) error {
	tx := g.Db
	//ids := strings.Split(removeInput.Host, ",")
	if err := (&dao.Node{}).Del(c, tx, removeInput.Host); err != nil {
		middleware.ResponseError(c, 2002, err)
		return err
	}

	return nil
}
